@@ -1,16 +1,12 @@
 package MooseX::Adopt::Class::Accessor::Fast;
 
-our $VERSION = '0.009_031';
-$VERSION =~ tr/_//d;
+our $VERSION = 0.0001;
 
 $INC{'Class/Accessor/Fast.pm'} = __FILE__;
 
-package #don't index
-    Class::Accessor::Fast;
+package Class::Accessor::Fast;
 
-use Moose;
-use namespace::clean;
-with 'MooseX::Emulate::Class::Accessor::Fast';
+use base qw/MooseX::Emulate::Class::Accessor::Fast/;
 
 1;
 
@@ -37,15 +33,12 @@ you migrate your project from L<Class::Accessor::Fast>, to
 
 L<Moose>, L<Class::Accessor::Fast>, L<MooseX::Emulate::Class::Accessor::Fast>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-=over 4
+Matt S Trout
 
-=item Matt S Trout
-
-=item Guillermo Roditi (groditi) <groditi@cpan.org>
-
-=back
+With Contributions from:
+Guillermo Roditi (groditi) <groditi@cpan.org>
 
 =head1 LICENSE
 
